slepc-3.18.0 2022-10-01
Report Typos and Errors

# STGetMatrixTransformed

Gets the matrices associated with the transformed eigensystem.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STGetMatrixTransformed(ST st,PetscInt k,Mat *T)

Not collective, though parallel Mats are returned if the ST is parallel

### Input Parameters

| st | - the spectral transformation context
| k | - the index of the requested matrix (starting in 0)

### Output Parameters

| T | - the requested matrix

### See Also

STGetMatrix(), STGetNumMatrices()

### Level

developer

### Location

src/sys/classes/st/interface/stfunc.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages